import type { NextApiRequest, NextApiResponse } from 'next';
import { DEFAULT_MIDDLEWARE_ROUTER_METHOD } from './constants';
import { ApiErrorHandler } from './error-handler';
/**
 *  an utility type to shorten writing Record<string, T = unknown>
 */
export declare type TypedObject<T = unknown> = Record<string, T>;
/**
 *  a standard next.js api handler but with req.middleware available
 *  see [official doc](https://nextjs.org/docs/api-routes/introduction) for more details
 */
export declare type NextApiHandlerWithMiddleware<T = unknown, M extends TypedObject = TypedObject> = (req: NextApiRequestWithMiddleware<M>, res: NextApiResponse) => T | Promise<T>;
/**
 *  a standard next.js api request but with req.middleware available
 */
export interface NextApiRequestWithMiddleware<M extends TypedObject = TypedObject> extends NextApiRequest {
    middleware: M;
}
/**
 *  all api response combines success response & error response
 */
export declare type ApiResponse<T = unknown> = SuccessApiResponse<T> | ErrorApiResponse;
/**
 *  api response that has http status code 2xx with data
 */
export declare type SuccessApiResponse<T> = {
    success: true;
    data: T;
};
/**
 *  api response that has http status code 4xx or 5xx with error message
 */
export declare type ErrorApiResponse = {
    success: false;
    message: string;
};
/**
 * RouterBuilder options
 */
export declare type RouterBuilderOptions = Partial<{
    error: ApiErrorHandler;
    showMessage: boolean;
}>;
export declare type InternalMiddlewareMap = Partial<Record<MiddlewareRouterMethod, NextApiHandlerWithMiddleware<TypedObject, any>[]>>;
export declare type RouterMethod = 'GET' | 'HEAD' | 'PATCH' | 'OPTIONS' | 'CONNECT' | 'DELETE' | 'TRACE' | 'POST' | 'PUT';
export declare type MiddlewareRouterMethod = typeof DEFAULT_MIDDLEWARE_ROUTER_METHOD | RouterMethod;
export declare type AddMiddleware<R> = {
    <T extends TypedObject = TypedObject, M extends TypedObject = TypedObject>(method: MiddlewareRouterMethod, handler: NextApiHandlerWithMiddleware<T, M>): R;
    <T extends TypedObject = TypedObject, M extends TypedObject = TypedObject>(handler: NextApiHandlerWithMiddleware<T, M>): R;
};
