import type { NextApiHandler } from 'next';
import { ExpressLikeRouter } from './express-like-router';
import { RouterBuilderOptions } from './type';
/**
 * A router builder is next api handler builder that exposes express-like api.
 *
 * ### Example (basic usage)
 * ```js
 * // In next.js /pages/api/[route]
 * import { RouterBuilder } from 'next-api-handler'
 * const router = new RouterBuilder().build()
 * export default router
 * ```
 *
 * ### Example (add RESTful method)
 * ```js
 * import { RouterBuilder } from 'next-api-handler'
 * const router = new RouterBuilder().get((req, res) => "RESPONSE")
 * export default router
 * ```
 *
 * ### Example (add async method)
 * ```js
 * import { RouterBuilder } from 'next-api-handler'
 * const handler = new RouterBuilder().get(async (req, res) => "ASYNC RESPONSE")
 * export default router
 * ```
 *
 * @returns a builder that can build a next.js api handler.
 */
export declare class RouterBuilder extends ExpressLikeRouter {
    private readonly routerOptions;
    constructor(options?: RouterBuilderOptions);
    build(): NextApiHandler;
    private applyErrorHandler;
    private handleSendSuccessResponse;
    private resolveMiddlewareListAndQueue;
    private getMiddlewarePromiseList;
    private resolveMiddlewareQueue;
}
